==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/SignInActivity.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.OffsetDateTime;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "lastSignInDateTime", 
    "lastSignInRequestId"})
@JsonInclude(Include.NON_NULL)
public class SignInActivity implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("lastSignInDateTime")
    protected OffsetDateTime lastSignInDateTime;

    @JsonProperty("lastSignInRequestId")
    protected String lastSignInRequestId;

    protected SignInActivity() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.signInActivity";
    }

    @Property(name="lastSignInDateTime")
    @JsonIgnore
    public Optional<OffsetDateTime> getLastSignInDateTime() {
        return Optional.ofNullable(lastSignInDateTime);
    }

    public SignInActivity withLastSignInDateTime(OffsetDateTime lastSignInDateTime) {
        SignInActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.signInActivity");
        _x.lastSignInDateTime = lastSignInDateTime;
        return _x;
    }

    @Property(name="lastSignInRequestId")
    @JsonIgnore
    public Optional<String> getLastSignInRequestId() {
        return Optional.ofNullable(lastSignInRequestId);
    }

    public SignInActivity withLastSignInRequestId(String lastSignInRequestId) {
        SignInActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.signInActivity");
        _x.lastSignInRequestId = lastSignInRequestId;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private OffsetDateTime lastSignInDateTime;
        private String lastSignInRequestId;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder lastSignInDateTime(OffsetDateTime lastSignInDateTime) {
            this.lastSignInDateTime = lastSignInDateTime;
            this.changedFields = changedFields.add("lastSignInDateTime");
            return this;
        }

        public Builder lastSignInRequestId(String lastSignInRequestId) {
            this.lastSignInRequestId = lastSignInRequestId;
            this.changedFields = changedFields.add("lastSignInRequestId");
            return this;
        }

        public SignInActivity build() {
            SignInActivity _x = new SignInActivity();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.signInActivity";
            _x.lastSignInDateTime = lastSignInDateTime;
            _x.lastSignInRequestId = lastSignInRequestId;
            return _x;
        }
    }

    private SignInActivity _copy() {
        SignInActivity _x = new SignInActivity();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.lastSignInDateTime = lastSignInDateTime;
        _x.lastSignInRequestId = lastSignInRequestId;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("SignInActivity[");
        b.append("lastSignInDateTime=");
        b.append(this.lastSignInDateTime);
        b.append(", ");
        b.append("lastSignInRequestId=");
        b.append(this.lastSignInRequestId);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/SignInActivity.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.OffsetDateTime;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "lastNonInteractiveSignInDateTime", 
    "lastNonInteractiveSignInRequestId", 
    "lastSignInDateTime", 
    "lastSignInRequestId"})
@JsonInclude(Include.NON_NULL)
public class SignInActivity implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("lastNonInteractiveSignInDateTime")
    protected OffsetDateTime lastNonInteractiveSignInDateTime;

    @JsonProperty("lastNonInteractiveSignInRequestId")
    protected String lastNonInteractiveSignInRequestId;

    @JsonProperty("lastSignInDateTime")
    protected OffsetDateTime lastSignInDateTime;

    @JsonProperty("lastSignInRequestId")
    protected String lastSignInRequestId;

    protected SignInActivity() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.signInActivity";
    }

    @Property(name="lastNonInteractiveSignInDateTime")
    @JsonIgnore
    public Optional<OffsetDateTime> getLastNonInteractiveSignInDateTime() {
        return Optional.ofNullable(lastNonInteractiveSignInDateTime);
    }

    public SignInActivity withLastNonInteractiveSignInDateTime(OffsetDateTime lastNonInteractiveSignInDateTime) {
        SignInActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.signInActivity");
        _x.lastNonInteractiveSignInDateTime = lastNonInteractiveSignInDateTime;
        return _x;
    }

    @Property(name="lastNonInteractiveSignInRequestId")
    @JsonIgnore
    public Optional<String> getLastNonInteractiveSignInRequestId() {
        return Optional.ofNullable(lastNonInteractiveSignInRequestId);
    }

    public SignInActivity withLastNonInteractiveSignInRequestId(String lastNonInteractiveSignInRequestId) {
        SignInActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.signInActivity");
        _x.lastNonInteractiveSignInRequestId = lastNonInteractiveSignInRequestId;
        return _x;
    }

    @Property(name="lastSignInDateTime")
    @JsonIgnore
    public Optional<OffsetDateTime> getLastSignInDateTime() {
        return Optional.ofNullable(lastSignInDateTime);
    }

    public SignInActivity withLastSignInDateTime(OffsetDateTime lastSignInDateTime) {
        SignInActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.signInActivity");
        _x.lastSignInDateTime = lastSignInDateTime;
        return _x;
    }

    @Property(name="lastSignInRequestId")
    @JsonIgnore
    public Optional<String> getLastSignInRequestId() {
        return Optional.ofNullable(lastSignInRequestId);
    }

    public SignInActivity withLastSignInRequestId(String lastSignInRequestId) {
        SignInActivity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.signInActivity");
        _x.lastSignInRequestId = lastSignInRequestId;
        return _x;
    }

    public SignInActivity withUnmappedField(String name, Object value) {
        SignInActivity _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private OffsetDateTime lastNonInteractiveSignInDateTime;
        private String lastNonInteractiveSignInRequestId;
        private OffsetDateTime lastSignInDateTime;
        private String lastSignInRequestId;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder lastNonInteractiveSignInDateTime(OffsetDateTime lastNonInteractiveSignInDateTime) {
            this.lastNonInteractiveSignInDateTime = lastNonInteractiveSignInDateTime;
            this.changedFields = changedFields.add("lastNonInteractiveSignInDateTime");
            return this;
        }

        public Builder lastNonInteractiveSignInRequestId(String lastNonInteractiveSignInRequestId) {
            this.lastNonInteractiveSignInRequestId = lastNonInteractiveSignInRequestId;
            this.changedFields = changedFields.add("lastNonInteractiveSignInRequestId");
            return this;
        }

        public Builder lastSignInDateTime(OffsetDateTime lastSignInDateTime) {
            this.lastSignInDateTime = lastSignInDateTime;
            this.changedFields = changedFields.add("lastSignInDateTime");
            return this;
        }

        public Builder lastSignInRequestId(String lastSignInRequestId) {
            this.lastSignInRequestId = lastSignInRequestId;
            this.changedFields = changedFields.add("lastSignInRequestId");
            return this;
        }

        public SignInActivity build() {
            SignInActivity _x = new SignInActivity();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.signInActivity";
            _x.lastNonInteractiveSignInDateTime = lastNonInteractiveSignInDateTime;
            _x.lastNonInteractiveSignInRequestId = lastNonInteractiveSignInRequestId;
            _x.lastSignInDateTime = lastSignInDateTime;
            _x.lastSignInRequestId = lastSignInRequestId;
            return _x;
        }
    }

    private SignInActivity _copy() {
        SignInActivity _x = new SignInActivity();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.lastNonInteractiveSignInDateTime = lastNonInteractiveSignInDateTime;
        _x.lastNonInteractiveSignInRequestId = lastNonInteractiveSignInRequestId;
        _x.lastSignInDateTime = lastSignInDateTime;
        _x.lastSignInRequestId = lastSignInRequestId;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("SignInActivity[");
        b.append("lastNonInteractiveSignInDateTime=");
        b.append(this.lastNonInteractiveSignInDateTime);
        b.append(", ");
        b.append("lastNonInteractiveSignInRequestId=");
        b.append(this.lastNonInteractiveSignInRequestId);
        b.append(", ");
        b.append("lastSignInDateTime=");
        b.append(this.lastSignInDateTime);
        b.append(", ");
        b.append("lastSignInRequestId=");
        b.append(this.lastSignInRequestId);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
